package org.iotivity.bridge.homeserver.handler.server;

import android.util.Log;

import org.iotivity.OCRequest;
import org.iotivity.OCRequestHandler;
import org.iotivity.OCStatus;
import org.iotivity.bridge.homeserver.BridgeService;
import org.iotivity.bridge.homeserver.model.Light;
import org.iotivity.bridge.homeserver.BridgeServerActivity;
import org.iotivity.oc.OcCborException;
import org.iotivity.oc.OcRepresentation;
import org.iotivity.oc.OcUtils;

public class PostLightRequestHandler implements OCRequestHandler {

    private static final String TAG = PostLightRequestHandler.class.getSimpleName();

    private BridgeService service;
    private Light light;

    public PostLightRequestHandler(BridgeService service, Light light) {
        this.service = service;
        this.light = light;
    }

    @Override
    public void handler(OCRequest request, int interfaces) {
        Log.d(TAG, "inside Post Light Request Handler");

        service.msg("Post Light:");

        OcRepresentation rep = new OcRepresentation(request.getRequestPayload());
        while (rep != null) {
            try {
                if (Light.SWITCH_KEY.equalsIgnoreCase(rep.getKey())) {
                    light.setSwitchOn(rep.getBoolean(Light.SWITCH_KEY));
                    service.msg("\t\t" + Light.SWITCH_KEY + ": " + light.isSwitchOn());
                }
            } catch (OcCborException e) {
                // ignore -- no switch value
            }

            try {
                if (Light.DIMMING_SETTING_KEY.equalsIgnoreCase(rep.getKey())) {
                    light.setDimmingLevel((int) rep.getLong(Light.DIMMING_SETTING_KEY));
                    service.msg("\t\t" + Light.DIMMING_SETTING_KEY + ": " + light.getDimmingLevel());
                }
            } catch (OcCborException e) {
                // ignore -- no dimming value
            }

            rep = rep.getNext();
        }

        service.printLine();
        OcUtils.sendResponse(request, OCStatus.OC_STATUS_CHANGED);
    }
}
